@@ -29,12 +29,11 @@
 
 BEGIN_GNOME_DECLS
 
-#define GNOME_DOCK(obj) \
-  GTK_CHECK_CAST (obj, gnome_dock_get_type (), GnomeDock)
-#define GNOME_DOCK_CLASS(klass) \
-  GTK_CHECK_CLASS_CAST (klass, gnome_dock_get_type (), GnomeDockClass)
-#define GNOME_IS_DOCK(obj) \
-  GTK_CHECK_TYPE (obj, gnome_dock_get_type ())
+#define GNOME_TYPE_DOCK            (gnome_dock_get_type ())
+#define GNOME_DOCK(obj)            (GTK_CHECK_CAST ((obj), GNOME_TYPE_DOCK, GnomeDock))
+#define GNOME_DOCK_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GNOME_TYPE_DOCK, GnomeDockClass))
+#define GNOME_IS_DOCK(obj)         (GTK_CHECK_TYPE ((obj), GNOME_TYPE_DOCK))
+#define GNOME_IS_DOCK_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_DOCK))
 
 typedef enum
 {
